@@ -107,7 +107,9 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles):
         #
     @property
     def project_path(self) -> str:#------------------------------------------------------
-        return self.awrde.Project.Path    
+        raw_path = self.awrde.Project.Path
+        path = raw_path.replace('\\','/')
+        return path   
         #
     @property
     def project_frequencies(self) -> np.ndarray:#------------------------------------------------
