@@ -475,6 +475,10 @@ class _Measurement(_ProcessDefinitions):
         '''Returns name of measurement'''
         return self._meas.Name
         #
+    def modify_measurement(self, new_measurement_name: str):#-------------------------------
+        '''Update measurement name. Does not check for validity'''
+        self._meas.Name = new_measurement_name
+        #
     @property
     def measurement_doc_source(self) -> str:#---------------------------------------------
         '''Returns doucument source of the measurement'''
