@@ -5,6 +5,7 @@ import itertools
 
 _Elements = common_utils._Elements
 _Equations = common_utils._Equations
+_Document_Methods = common_utils._Document_Methods
 #
 #*****************************************************************************************************
 #
@@ -149,14 +150,14 @@ class _Schematics():
 #
 #*****************************************************************************************************
 #
-class _Schematic(_Elements, _Equations): 
+class _Schematic(_Elements, _Equations, _Document_Methods): 
 
     def __init__(self, circuit_schematic):
         self._circuit_schematic = circuit_schematic
         _Elements.__init__(self, self._circuit_schematic, 'Schematic')
         _Equations.__init__(self, self._circuit_schematic)
-        
-
+        _Document_Methods.__init__(self, self._circuit_schematic)
+        #
     @property
     def circuit_schematic_name(self) -> str:
         '''Returns name of circuit schematics'''
